﻿namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Core.Items;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Modules;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Occupancy;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Shared.Networking;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;
    using Eco.Gameplay.Housing.PropertyValues;
    using Eco.Gameplay.Civics.Objects;
    using Eco.Gameplay.Settlements;
    using Eco.Gameplay.Systems.NewTooltip;
    using Eco.Core.Controller;
    using Eco.Core.Utils;
	using Eco.Gameplay.Components.Storage;
    using static Eco.Gameplay.Housing.PropertyValues.HomeFurnishingValue;
    using Eco.Gameplay.Items.Recipes;

    [Serialized]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(LinkComponent))]
    [RequireComponent(typeof(PublicStorageComponent))]
    [RequireComponent(typeof(HousingComponent))]
    [RequireComponent(typeof(ForSaleComponent))]
    [Tag("Usable")]
    [Ecopedia("Housing Objects", "Kitchen", subPageName: "Salt Basket Item")]
    public partial class SaltBasketObject : WorldObject, IRepresentsItem
    {
        public virtual Type RepresentedItemType => typeof(SaltBasketItem);
        public override LocString DisplayName => Localizer.DoStr("Salt Basket");
        public override TableTextureMode TableTexture => TableTextureMode.Wood;

        protected override void Initialize()
        {
            this.GetComponent<HousingComponent>().HomeValue = SaltBasketItem.homeValue;
            var storage = this.GetComponent<PublicStorageComponent>();
            storage.Initialize(60);
        }
		protected override void PostInitialize()
        {
            base.PostInitialize();
            this.GetComponent<LinkComponent>().Initialize(50);
        }
        partial void ModsPreInitialize();
        partial void ModsPostInitialize();
    }

    [Serialized]
    [LocDisplayName("Salt Basket")]
    [LocDescription("A storage for all kinds of things !")]
    [Ecopedia("Housing Objects", "Kitchen", createAsSubPage: true)]
    [Tag("Housing")]
    public partial class SaltBasketItem : WorldObjectItem<SaltBasketObject>
    {
        public override HomeFurnishingValue HomeValue => homeValue;
        public static readonly HomeFurnishingValue homeValue = new HomeFurnishingValue()
        {
            ObjectName                              = typeof(SaltBasketObject).UILink(),
            Category                                = HousingConfig.GetRoomCategory("Kitchen"),
            BaseValue                               = 1,            
        };
    }
	
    [RequiresSkill(typeof(FarmingSkill), 0)]
    [Ecopedia("Housing Objects", "Kitchen", subPageName: "Salt Basket Item")]
    public partial class SaltBasketRecipe : RecipeFamily
    {
        public SaltBasketRecipe()
        {
            var recipe = new Recipe();
            recipe.Init("SaltBasket", Localizer.DoStr("Salt Basket"),
                new List<IngredientElement>
                {
                    new IngredientElement(typeof(PlantFibersItem), 5)
                },
                new List<CraftingElement>
                {
                    new CraftingElement<SaltBasketItem>()
                });
            this.Recipes = new List<Recipe> { recipe };
            this.LaborInCalories = CreateLaborInCaloriesValue(1);
            this.CraftMinutes = CreateCraftTimeValue(1);
            this.Initialize(Localizer.DoStr("Salt Basket"), typeof(SaltBasketRecipe));
            CraftingComponent.AddRecipe(typeof(FarmersTableObject), this);
        }
        partial void ModsPreInitialize();
        partial void ModsPostInitialize();
    }
}
